diff --git a/glide-core/src/cluster_scan_container.rs b/glide-core/src/cluster_scan_container.rs index 20c464a186..38cb1ec76d 100644 --- a/glide-core/src/cluster_scan_container.rs +++ b/glide-core/src/cluster_scan_container.rs @@ -1,5 +1,5 @@ /** - * Copyright GLIDE-for-Redis Project Contributors - SPDX Identifier: Apache-2.0 + * Copyright Valkey GLIDE Project Contributors - SPDX Identifier: Apache-2.0 */ use logger_core::log_debug; use nanoid::nanoid; diff --git a/java/DEVELOPER.md b/java/DEVELOPER.md index 58fba9129a..743a9be57e 100644 --- a/java/DEVELOPER.md +++ b/java/DEVELOPER.md @@ -243,8 +243,8 @@ Refer to https://valkey.io/docs/topics/transactions/ for more details about how [BaseTransaction.java](https://github.com/aws/glide-for-redis/blob/main/java/client/src/main/java/glide/api/models/BaseTransaction.java) and the methods within the command interfaces will both contain documentation on how the command operates. In the command interface each command's javadoc should contain: -- Detail on when the Redis started supporting the command (if it wasn't initially implemented in 6.0.0 or before). -- A link to the Redis documentation. +- Detail on when Valkey started supporting the command (if it wasn't initially implemented in 6.0.0 or before). +- A link to the Valkey documentation. - Information about the function parameters. - Any glide-core implementation details, such as how glide-core manages default routing for the command. Reference this [link](https://github.com/aws/glide-for-redis/blob/4df0dd939b515dbf9da0a00bfca6d3ad2f27440b/java/client/src/main/java/glide/api/commands/SetBaseCommands.java#L119) for an example. - The command's return type. In the [BaseTransaction.java](https://github.com/aws/glide-for-redis/blob/main/java/client/src/main/java/glide/api/models/BaseTransaction.java) file, include "Command Response" before specifying the return type. diff --git a/java/client/src/main/java/glide/api/commands/GenericClusterCommands.java b/java/client/src/main/java/glide/api/commands/GenericClusterCommands.java index 94907d2725..2d849fa37b 100644 --- a/java/client/src/main/java/glide/api/commands/GenericClusterCommands.java +++ b/java/client/src/main/java/glide/api/commands/GenericClusterCommands.java @@ -30,7 +30,7 @@ public interface GenericClusterCommands { * href="https://github.com/aws/glide-for-redis/wiki/General-Concepts#custom-command">Valkey * GLIDE Wiki for details on the restrictions and limitations of the custom command API. * @param args Arguments for the custom command including the command name. - * @return Response from Redis containing an Object. + * @return The returning value depends on the executed command. * @example *
{@code
      * ClusterValue data = client.customCommand(new String[] {"ping"}).get();
@@ -51,7 +51,7 @@ public interface GenericClusterCommands {
      * @param args Arguments for the custom command including the command name
      * @param route Specifies the routing configuration for the command. The client will route the
      *     command to the nodes defined by route.
-     * @return The returning value depends on the executed command.
+     * @return The returning value depends on the executed command and route.
      * @example
      *     
{@code
      * ClusterValue result = clusterClient.customCommand(new String[]{ "CONFIG", "GET", "maxmemory"}, ALL_NODES).get();
diff --git a/python/DEVELOPER.md b/python/DEVELOPER.md
index dbf7e9b5c0..acba11973c 100644
--- a/python/DEVELOPER.md
+++ b/python/DEVELOPER.md
@@ -124,7 +124,7 @@ Before starting this step, make sure you've installed all software requirments.
         ```bash
         pytest --asyncio-mode=auto
         ```
-        > **Note:** To run redis modules tests, add -k "test_redis_modules.py".
+        > **Note:** To run redis modules tests, add -k "test_server_modules.py".
 
 -   Install Python development requirements with:
 
diff --git a/python/pytest.ini b/python/pytest.ini
index 7c29dff74f..971d5c1681 100644
--- a/python/pytest.ini
+++ b/python/pytest.ini
@@ -2,4 +2,4 @@
 markers =
     smoke_test: mark a test as a build verification testing.
 # TODO: Remove pubsub exclusion after the flakey tests are fixed
-addopts = -k "not redis_modules and not pubsub"
+addopts = -k "not server_modules and not pubsub"
diff --git a/python/python/glide/__init__.py b/python/python/glide/__init__.py
index c755f201f3..f1f758aeed 100644
--- a/python/python/glide/__init__.py
+++ b/python/python/glide/__init__.py
@@ -31,7 +31,7 @@
     InsertPosition,
     UpdateOptions,
 )
-from glide.async_commands.redis_modules import json
+from glide.async_commands.server_modules import json
 from glide.async_commands.sorted_set import (
     AggregationType,
     GeoSearchByBox,
diff --git a/python/python/glide/async_commands/redis_modules/json.py b/python/python/glide/async_commands/server_modules/json.py
similarity index 100%
rename from python/python/glide/async_commands/redis_modules/json.py
rename to python/python/glide/async_commands/server_modules/json.py
diff --git a/python/python/tests/tests_redis_modules/test_json.py b/python/python/tests/tests_server_modules/test_json.py
similarity index 98%
rename from python/python/tests/tests_redis_modules/test_json.py
rename to python/python/tests/tests_server_modules/test_json.py
index f425cd5670..c6ee1a72f4 100644
--- a/python/python/tests/tests_redis_modules/test_json.py
+++ b/python/python/tests/tests_server_modules/test_json.py
@@ -4,8 +4,8 @@
 
 import pytest
 from glide.async_commands.core import ConditionalChange, InfoSection
-from glide.async_commands.redis_modules import json
-from glide.async_commands.redis_modules.json import JsonGetOptions
+from glide.async_commands.server_modules import json
+from glide.async_commands.server_modules.json import JsonGetOptions
 from glide.config import ProtocolVersion
 from glide.constants import OK
 from glide.exceptions import RequestError
diff --git a/java/client/src/main/java/glide/api/models/commands/stream/StreamPendingOptionsBinary.java b/java/client/src/main/java/glide/api/models/commands/stream/StreamPendingOptionsBinary.java
index 7fea5aebb0..2f7772a64f 100644
--- a/java/client/src/main/java/glide/api/models/commands/stream/StreamPendingOptionsBinary.java
+++ b/java/client/src/main/java/glide/api/models/commands/stream/StreamPendingOptionsBinary.java
@@ -18,8 +18,8 @@
 @Builder
 public class StreamPendingOptionsBinary {
 
-    /** Redis api string to designate IDLE or minimum idle time */
-    public static final GlideString IDLE_TIME_REDIS_API_GLIDE_STRING = gs("IDLE");
+    /** Valkey api string to designate IDLE or minimum idle time */
+    public static final GlideString IDLE_TIME_VALKEY_API_GLIDE_STRING = gs("IDLE");
 
     /** Filters pending entries by their idle time - in Milliseconds */
     private final Long minIdleTime; // Milliseconds
@@ -30,12 +30,12 @@ public class StreamPendingOptionsBinary {
     /**
      * Convert StreamPendingOptions arguments to a string array
      *
      * @return arguments converted to an array to be consumed by Redis
      */
     public GlideString[] toArgs(StreamRange start, StreamRange end, long count) {
         List optionArgs = new ArrayList<>();
         if (minIdleTime != null) {
-            optionArgs.add(IDLE_TIME_REDIS_API_GLIDE_STRING);
+            optionArgs.add(IDLE_TIME_VALKEY_API_GLIDE_STRING);
             optionArgs.add(gs(Long.toString(minIdleTime)));
         }
 
@@ -30,12 +30,12 @@ public class StreamPendingOptionsBinary {
      * Convert StreamPendingOptions arguments to a string array
      *
-     * @return arguments converted to an array to be consumed by Redis
+     * @return arguments converted to an array to be consumed by Valkey
      */
     public GlideString[] toArgs(StreamRange start, StreamRange end, long count) {